# cortado: high performance 100% Python package for machine learning

## Main features:
* native support for both numeric and categorical data
* innovative feature engineering: virtual data columns and easy conversions between numeric and categorical data
* out of core data processing: process dataframes bigger than RAM
* implementation of XGBoost logistic in 500 lines of Python code, faster than original C++ implementation (using Numba jit under the hood)
* easy to extend, written in functional style for easy composition
* works well with pandas dataframes

## Demo notebooks:
* intro
